Index: trunk/psLib/src/sys/psConfigure.h
===================================================================
--- trunk/psLib/src/sys/psConfigure.h	(revision 9538)
+++ trunk/psLib/src/sys/psConfigure.h	(revision 10286)
@@ -13,6 +13,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.8 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-10-13 21:13:48 $
+ *  @version $Revision: 1.9 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-11-29 21:33:09 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -30,9 +30,18 @@
  *  Returns the current psLib version name as a string.
  *
  *  @return char*: String with version name.
  */
 psString psLibVersion(
     void
 );
+
+/** Get current psLib version (full identification)
+ *
+ *  Returns the current psLib version name and other information identifying the compilation.
+ *
+ *  @return psString: String with identity.
+ */
+psString psLibVersionLong(void);
+
 
 /** Initializes persistent memory.
@@ -30,9 +30,18 @@
  *  Returns the current psLib version name as a string.
  *
- *  @return char*: String with version name.
+ *  @return psString: String with version name.
  */
 psString psLibVersion(
